######################
imagedata-format-biff
######################

|Docs Badge| |buildstatus|  |coverage| |pypi|


Imagedata plugin for biff image files.


.. |Docs Badge| image:: https://readthedocs.org/projects/imagedata/badge/
    :alt: Documentation Status
    :target: https://imagedata.readthedocs.io

.. |buildstatus| image:: https://github.com/erling6232/imagedata_format_biff/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/erling6232/imagedata_format_biff/actions?query=branch%3Amaster
    :alt: Build Status

.. _buildstatus: https://github.com/erling6232/imagedata_format_biff/actions

.. |coverage| image:: https://codecov.io/gh/erling6232/imagedata_format_biff/branch/main/graph/badge.svg?token=1OPGNXJ8Z3
    :alt: Coverage
    :target: https://codecov.io/gh/erling6232/imagedata_format_biff

.. |pypi| image:: https://img.shields.io/pypi/v/imagedata-format-biff.svg
    :target: https://pypi.python.org/pypi/imagedata-format-biff
    :alt: PyPI Version

